{% extends "admin/base_site.html" %}
{% load i18n %}
{% load url from future %}
{% block userlinks %}{% url 'django-admindocs-docroot' as docsroot %}{% if docsroot %}<a href="{{ docsroot }}">{% trans 'Documentation' %}</a> / {% endif %}{% trans 'Change password' %} / <a href="../../logout/">{% trans 'Log out' %}</a>{% endblock %}
{% block breadcrumbs-relative %}
	<li><a href="../../">{% trans 'Admin' %}</a></li>
	<li class='last'>{% trans 'Password change' %}</li>
{% endblock %}

{% block title %}{% trans 'Password change successful' %}{% endblock %}

{% block content %}

<p>{% trans 'Your password was changed.' %}</p>

{% endblock %}
